# AnADAMA2 #

----

 * For complete documentation, please see the [AnADAMA2 User Manual](https://bitbucket.org/biobakery/anadama2/wiki/Home).

 * Please direct questions to the AnADAMA2 google group: TBD (subscribe to receive AnADAMA2 news).

 * If you use the AnADAMA2 software, please cite our manuscript: TBD

----

AnADAMA2 is the next generation of AnADAMA (Another Automated Data Analysis Management Application). AnADAMA is a tool to capture your workflow and execute it efficiently on your local machine or in a grid compute environment (ie. sun grid engine or slurm).

